@@ -36,9 +36,10 @@ end
 # Accepts the following options:
 # - :size - number of connections to pool, defaults to 5
 # - :timeout - amount of time to wait for a connection if none currently available, defaults to 5 seconds
+# - :auto_reload_after_fork - automatically drop all connections after fork, defaults to true
 #
 class ConnectionPool
-  DEFAULTS = {size: 5, timeout: 5}
+  DEFAULTS = {size: 5, timeout: 5, auto_reload_after_fork: true}
 
   def self.wrap(options, &block)
     Wrapper.new(options, &block)
@@ -50,11 +51,12 @@ class ConnectionPool
 
     def self.after_fork
       INSTANCES.values.each do |pool|
+        next unless pool.auto_reload_after_fork
+
         # We're on after fork, so we know all other threads are dead.
         # All we need to do is to ensure the main thread doesn't have a
         # checked out connection
         pool.checkin(force: true)
-
         pool.reload do |connection|
           # Unfortunately we don't know what method to call to close the connection,
           # so we try the most common one.
@@ -92,6 +94,7 @@ class ConnectionPool
 
     @size = Integer(options.fetch(:size))
     @timeout = options.fetch(:timeout)
+    @auto_reload_after_fork = options.fetch(:auto_reload_after_fork)
 
     @available = TimedStack.new(@size, &block)
     @key = :"pool-#{@available.object_id}"
@@ -159,6 +162,8 @@ class ConnectionPool
 
   # Size of this connection pool
   attr_reader :size
+  # Automatically drop all connections after fork
+  attr_reader :auto_reload_after_fork
 
   # Number of pool entries available for checkout at this instant.
   def available
